/*
 * Author: Nigel Kukard  <nkukard@lbsd.net>
 * Desc: Firewall stuff...
 * Date: 25/05/2003
 * License: GPL
*/


#include <getopt.h>
#include <glib.h>
#include <errno.h>
#include <fcntl.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include "../config.h"
#include "common.h"
#include "xmlConf.h"



// Function to write firewall to file
static int writeFirewall(GList *ruleList, char *filename)
{
	int fd;
	int fuct = 0;
	char *buffer;


	// Write rule by rule to file	
	void writeRule(gpointer data, gpointer user_data)
	{
		int res;
		
		if (!fuct)
		{
			res = write(fd,data,strlen(data));
			if (res < 0)
			{
				fprintf(stderr,"Failed to write to file: %s\n",strerror(errno));
				fuct = 1;
			}
		}
	}


	// Open firewall file	
	fd = open(filename,O_CREAT|O_TRUNC|O_WRONLY,S_IREAD|S_IWRITE);
	if (fd < 0)
	{
		fprintf(stderr,"Failed to open file \"%s\": %s\n",filename,strerror(errno));
		return(-1);
	}

	buffer = (char *) malloc0(BUFFER_SIZE);
	// FIXME - add date
	snprintf(buffer,BUFFER_SIZE,"# Generated using BWM Firewall v%s: %s\n",PACKAGE_VERSION,"DATE");
	write(fd,buffer,strlen(buffer));
	
	// Loop with all rules
	g_list_foreach(ruleList,writeRule,NULL);

	// Finally close file descriptor
	close(fd);

	return(fuct);
}


// Print out our usage
void printUsage(char **argv)
{
	printf("Usage: %s [-h|--help] [-f|--force] [-c|--config=<config_file>] [-o|--output=<output_file>]\n",argv[0]);
}


// Obviously we need our main function
int main (int argc, char **argv)
{
	GList *fw;
	int c;
	char *configFile = CONFIG_FILE;
	char *outputFile = IPTABLES_FILE;
	int force = 0;
	int res = 1; // signal we return error status
	
	
	// Our options
	struct option long_options[] =
	{
		{"config",1,0,'c'},
		{"force",0,0,'f'},
		{"help",0,0,'h'},
		{"output",1,0,'o'},
		{0,0,0,0}
	};
	

	printf("BWM Firewall v%s - Copyright (c) 2003 Linux Based Systems Design\n\n",PACKAGE_VERSION);

	// Check if we have no args
	if (argc == 1)
	{
		printUsage(argv);
		return(1);
	}
	
	// Loop with options
	while (1)
	{
		int option_index = 0;
		
		// Process
		c = getopt_long(argc,argv,"c:hfo:",long_options,&option_index);
		if (c == -1)
			break;

		// Check...
		switch (c)
		{
			case 'c':
				configFile = strdup(optarg);
				break;
			case 'f':
				force = 1;
				break;		
			case 'h':
				printUsage(argv);
				return(0);
			case 'o':
				outputFile = strdup(optarg);
				break;
		}
		
	}

	// Let us know about ahy unknown options
	if (optind < argc)
	{
		while (optind < argc)
			fprintf(stderr,"%s: invalid option -- %s\n",argv[0],argv[optind++]);
		return(1);
	}

	// Load configuration
	printf("Loading configuration from \"%s\"...\n",configFile);	
	fw = createFirewallRules(configFile);

	// Write out firewall
	if (fw)
	{
		printf("Writing IPTables configuration to \"%s\"...\n",outputFile);
		res = writeFirewall(fw,outputFile);
	}
	
	// Return result code
	return res;
}


