/*
 * Author: Nigel Kukard  <nkukard@lbsd.net>
 * Desc: Graph headers for bwm_graph
 * Date: 25/05/2003
 * License: GPL
*/

#ifndef _GRAPH_H
#define _GRAPH_H


#define RRD_STEP 30

#include "common.h"


// Macro to add a double   -a ....  parameter to a char ** array
#define ADD_DOUBLE_PARAM(paramList,numParams,param,format,...) \
		{ \
			int i; \
			\
			numParams += 2; \
			paramList = (char **) realloc(paramList, numParams * sizeof(char*)); \
			for (i = numParams - 2; i < numParams; i++) \
				paramList[i] = malloc0(BUFFER_SIZE); \
			strcpy(paramList[numParams - 2], param); \
			snprintf(paramList[numParams - 1], BUFFER_SIZE, format, __VA_ARGS__); \
		}

// Macro to add a single   -a   parameter to a char ** array
#define ADD_SINGLE_PARAM(paramList,numParams,format,...) \
		{ \
			int i; \
			\
			numParams += 1; \
			paramList = (char **) realloc(paramList, numParams * sizeof(char*)); \
			for (i = numParams - 1; i < numParams; i++) \
				paramList[i] = malloc0(BUFFER_SIZE); \
			snprintf(paramList[numParams - 1], BUFFER_SIZE, format, __VA_ARGS__); \
		}

// Macro to decide the correct date and time
#define STR_TIME(time_p,buffer_size,buffer) \
		{ \
			struct tm *tmp_tm; \
			\
			tmp_tm = localtime(time_p); \
			strftime(buffer,buffer_size,"%d/%m/%Y %T",tmp_tm); \
		}

enum sourceType_e
{
	COUNTER_NONE,
	COUNTER_PKT,
	COUNTER_SIZE_BIT,
	COUNTER_SIZE_BYTE,
	COUNTER_DROPPED,
	COUNTER_BURSTED
};

// Flow source stuff
struct graphSource_t
{
	char *flowRef;
	char *flowDisplayType;
	char *flowColor;
	enum sourceType_e flowCounter;
	
	unsigned long long int counterTotal;
	unsigned long long int counterAbsTotal;
	long int counterEntries;

	int first;
	int last;
	
	int counterTimeout;
};

// Graph options
struct graphOptions_t
{
	char *title;
	char *verticalTitle;
	time_t start;
	time_t end;
	char *outputFile;
	int graph_avg:1;
	int graph_total:1;
	int graph_maxRate:1;
	int graph_date:1;
};


// Function to create us a proper flow source
struct graphSource_t *createGraphSource(char *flow);
// Function to write out our rrd files, ready them for graphing
int writeRRDFile(GList *graphSources, struct graphOptions_t *options);
// Function to build ourselves the RRD files
int createRRDFiles(GList *graphSources, struct graphOptions_t *options);
// Write our graph, combined graph items and all
int writeGraphs(GList *graphSources, struct graphOptions_t *options);
	
#endif
