/*
 * Author: Nigel Kukard  <nkukard@lbsd.net>
 * Desc: Header stuff commonly used by more than 1 .c file
 * Date: 15/04/2003
 * License: GPL
*/


#ifndef _COMMON_H
#define _COMMON_H

#include <glib.h>
#include <linux/limits.h>
#include "libipq.h"


#define BUFFER_SIZE 4096

#define MAX_REFLEN 128

#define MAX_NAMELEN PATH_MAX

#define NUM_PRIO_BANDS	100

#define malloc0(xxxx) memset(malloc(xxxx),'\0',xxxx)


// Free memory list
struct pmem_t
{
	GList *freeList;
	GMutex *lock;
};

// Thread data
struct runnerData_t
{
	int daemon; // This is set to 1 if we are a daemon, and 0 if not
	
	GList *pktQueues; // List of our packet queues
	GList *flows; // List of our flows
	GList *groups; // List of our groups
	
	GCond *bandSignalCond;  // Signal used to tell us a band has changed
	GMutex *bandSignalLock;
	int queueChanged;
	GList *queueChangeList[NUM_PRIO_BANDS];  // List of bands changed
	GMutex *waitListLock;
	int queueWait;
	GList *queueWaitList[NUM_PRIO_BANDS];  // List of bands waiting
	
	struct ipq_handle *IPQHandle;  // ip_queue handle
	GMutex *IPQLock;
	
	struct pmem_t pmem;  // List of free memory we can use
};

// Flow data
struct flowData_t
{
	GList *pktQueues;
	GList *flows;
	GList *groups;
};


struct packet_t
{
	ipq_packet_msg_t *payload;
};



#endif

