/*
 * Author: Nigel Kukard  <nkukard@lbsd.net>
 * Desc: IPQ handling for bwmd
 * Date: 15/04/2003
 * License: GPL
*/


#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "autoclass.h"
#include "flow.h"
#include "ipq.h"
#include "libipq.h"



// Destroy the ipq handle
static void destroyIPQHandle(struct ipq_handle *h)
{
	ipq_perror("passer");
	ipq_destroy_handle(h);
}


// Return the ipq handle
static struct ipq_handle *getIPQHandle()
{	
	struct ipq_handle* h;
	int result;

	// Create our ipq socket
	h = ipq_create_handle(0, PF_INET, 1048576);
	if (!h)
	{
		fprintf(stderr,"Failed to create IPQ handle\n");
		destroyIPQHandle(h);
		return NULL;
	}
	
	// Set mode...
	result = ipq_set_mode(h, IPQ_COPY_PACKET, IPQ_BUFSIZE);
	if (result < 0)
	{
		fprintf(stderr,"Failed to set IPQ mode\n");
		destroyIPQHandle(h);
		return NULL;
	}

	return(h);
}


// Close the ipq handle
static void closeIPQHandle(struct ipq_handle *h)
{
	ipq_destroy_handle(h);
}


// Queue a packet
static int queuePacket(struct runnerData_t *runnerData, long int nfmark, struct packet_t *packet)
{
	struct pktQueue_t *foundQueue = NULL;
	struct flow_t *foundFlow = NULL;
	int status;
	int result;
	int drop = 0;


	// Our find functions
	void findQueue(void *data, void *user_data)
	{
		struct pktQueue_t *pktQueue = (struct pktQueue_t*) data;

		
		if (foundQueue) return;
		
		// Check if we found it
		if (pktQueue->nfmark == nfmark)
			foundQueue = pktQueue;
	}

	void findFlow(void *data, void *user_data)
	{
		struct flow_t *flow = (struct flow_t*) data;

		
		if (foundFlow) return;
		
		// Check if we found it
		if (flow->nfmark == nfmark)
			foundFlow = flow;
	}


	// Loop to see what we find... we have to have queues if we going to loop with them
	if (runnerData->pktQueues)
		g_list_foreach(runnerData->pktQueues,findQueue,NULL);
	// Now check if we found a flow??
	if (!foundQueue)
		g_list_foreach(runnerData->flows,findFlow,NULL);

	// Check if we have something
	if (!foundQueue && !foundFlow)
	{
		fprintf(stderr,"Queue or flow not found in processFlow() for %li\n", nfmark);
		return(-1);
	}

	// Now lets see if we don't have a queue... this means AUTO!
	if (!foundQueue)
	{
		struct ip_packet_t *ip_packet = (struct ip_packet_t *) packet->payload->payload;
		long int bandNum = -1;
		
/*		
		fprintf(stderr,"auto packet queue -> protocol = %i, src = %i.%i.%i.%i, dest = %i.%i.%i.%i, tos = 0x%x\n", ip_packet->protocol, 
				ip_packet->u_saddr.addr.a, ip_packet->u_saddr.addr.b, ip_packet->u_saddr.addr.c, ip_packet->u_saddr.addr.d, 
				ip_packet->u_daddr.addr.a, ip_packet->u_daddr.addr.b, ip_packet->u_daddr.addr.c, ip_packet->u_daddr.addr.d, 
				IPTOS_PREC(ip_packet->tos));
*/				
		// Process a TCP packet
		if (ip_packet->protocol == IPPROTO_TCP)
		{
			struct tcphdr *tcph = (struct tcphdr *) (packet->payload->payload + (ip_packet->ihl * 4));
/*	
			fprintf(stderr,"  tcp -> sport = %i, dport = %i, prec = 0x%x\n", ntohs(tcph->source), 
				ntohs(tcph->dest), IPTOS_PREC(ip_packet->tos));
*/
			bandNum = tcpPortToBand(bandNum,ntohs(tcph->dest));
			if (bandNum == -1)
				bandNum = tcpPortToBand(bandNum,ntohs(tcph->source));

		}

		// Process a ICMP packet
		if (ip_packet->protocol == IPPROTO_ICMP)
		{
			struct icmphdr *icmph = (struct icmphdr *) (packet->payload->payload + (ip_packet->ihl * 4));
/*	
			fprintf(stderr,"something: icmp = %i, type = %i\n", icmph->code, icmph->type);
*/
			bandNum = 5;
		}

		// Process a UDP packet
		if (ip_packet->protocol == IPPROTO_UDP)
		{
			struct udphdr *udph = (struct udphdr *) (packet->payload->payload + (ip_packet->ihl * 4));
/*	
			fprintf(stderr,"  udp -> sport = %i, dport = %i\n", ntohs(udph->source), 
				ntohs(udph->dest));
*/
			bandNum = udpPortToBand(bandNum,ntohs(udph->dest));
			if (bandNum == -1)
				bandNum = udpPortToBand(bandNum,ntohs(udph->source));
		}
	
		// If we didn't get anything set band number to 50, 50/50	
		if (bandNum == -1)
			bandNum = 50;

		foundQueue = foundFlow->pktQueues[bandNum];
	}
	
	
	// Lock flow before we fuck with it
	g_mutex_lock(foundQueue->lock);
	g_mutex_lock(P_FLOW(foundQueue,lock));

	// Check first of all if we fucked over our one of our queue limits
	if (QUEUE_EXCEEDED(foundQueue) || FLOW_QUEUE_EXCEEDED(foundQueue->parentFlow))
		drop = 1;
	// Check second of all if we fucked our min threshold over
	else if (TH_EXCEEDED(foundQueue,min_th))
	{
		int j = 1 + (int) (10.0 * rand() / (RAND_MAX + 1.0));

		if (TH_EXCEEDED(foundQueue,max_th))
		{
			if (j > 5)
				drop = 1;
		}
		else
		{
			if (j < 3)
				drop = 1;
		}
	}


	// Check if we must pass the packet
	if (!drop)
	{
		// Lock, queue... adjust stats
		foundQueue->packets = g_list_append(foundQueue->packets,packet);
		foundQueue->curSize += PKT_SIZE(packet);
		P_FLOW(foundQueue,curQueueSize) += PKT_SIZE(packet);
		foundQueue->curLen++;
		P_FLOW(foundQueue,curQueueLen)++;
		result = 1;  // Packet queued
	}
	else
	{
		// Tell kernel to drop packet
		g_mutex_lock(runnerData->IPQLock);
		status = ipq_set_verdict(runnerData->IPQHandle, PKT_ID(packet), NF_DROP, 0, NULL);
		g_mutex_unlock(runnerData->IPQLock);
		if (status < 0)
		{
			fprintf(stderr,"Failed to DROP packet\n");
			result = -1;
		}
		else
		{
			g_mutex_lock(P_FLOW(foundQueue,counterLock));
			P_FLOW(foundQueue,running).pktDropped++;
			g_mutex_unlock(P_FLOW(foundQueue,counterLock));
			result = 2; // Packet dropped
		}
		// Conserve memory
		g_mutex_lock(runnerData->pmem.lock);
		runnerData->pmem.freeList = g_list_append(runnerData->pmem.freeList,packet);
		g_mutex_unlock(runnerData->pmem.lock);
	}

	// Unlock flow
	g_mutex_unlock(P_FLOW(foundQueue,lock));
	g_mutex_unlock(foundQueue->lock);

	// If we have queued, signal a runner
	if (result == 1)
	{
		// Signal that we just added to the queue
		g_mutex_lock(runnerData->bandSignalLock);
		// Check if we havn't already gotten the queue listed
		// FIXME: check if we can't just add, high flow queue
		if (!g_list_find(runnerData->queueChangeList[foundQueue->prio],foundQueue))
			runnerData->queueChangeList[foundQueue->prio] = g_list_append(runnerData->queueChangeList[foundQueue->prio],foundQueue);
		runnerData->queueChanged = 1; // This basically signals immediate attention by the flow runner
		g_cond_signal(runnerData->bandSignalCond);
		g_mutex_unlock(runnerData->bandSignalLock);
	}
	
	return(result);
}


// Main IPQ->QUEUE thread
void *IPQRunner(void *data)
{
	unsigned char buf[IPQ_BUFSIZE];
	int status;
	struct runnerData_t *runnerData = (struct runnerData_t*) data;
	ipq_packet_msg_t *m;
	struct packet_t *packet;
	unsigned int pkt_len = 0;
	GList *listItem;


	if (!runnerData->daemon)
		printf("IPQ runner started...\n");

	// Get IPQ handle
	runnerData->IPQHandle = getIPQHandle();
	if (!runnerData->IPQHandle)
	{
		fprintf(stderr,"Failed to get IPQ handle\n");
		return(NULL);
	}

	// And loop
	while (1)
	{
		// Only loop when we have a packet
		status = ipq_read(runnerData->IPQHandle, buf, IPQ_BUFSIZE, 0);

		// Loop if timeout
		if (status == 0)
			continue;
		
		// Fail if error
		if (status < 0)
		{
			fprintf(stderr,"Failed to get packet from IPQ: %s\n",ipq_errstr());
			// Lock, we dead... accept it!
			destroyIPQHandle(runnerData->IPQHandle);
			return(NULL);
		}

		// We must have a packet... check
		switch (ipq_message_type(buf)) 
		{
			case NLMSG_ERROR:
				fprintf(stderr, "Received error message: IPQ = %s, SYSTEM = %s\n",ipq_errstr(),strerror(errno));
				break;

			case IPQM_PACKET: 
					
				// Get packet details...
				g_mutex_lock(runnerData->IPQLock);
				m = ipq_get_packet(buf);
				g_mutex_unlock(runnerData->IPQLock);
				pkt_len = sizeof(ipq_packet_msg_t) + m->data_len;

				// Get a packet or alloc it
				g_mutex_lock(runnerData->pmem.lock);
				listItem = g_list_first(runnerData->pmem.freeList);
				if (listItem == NULL)
				{
					
					packet = (struct packet_t*) malloc(sizeof(struct packet_t));
					packet->payload = (ipq_packet_msg_t*) malloc(IPQ_BUFSIZE);
				}
				else
				{
					packet = listItem->data;
					runnerData->pmem.freeList = g_list_remove(runnerData->pmem.freeList,packet);
				}
				g_mutex_unlock(runnerData->pmem.lock);
			
				// Copy packet
				memcpy(packet->payload,m,pkt_len);

				// Queue the packet...
				status = queuePacket(runnerData,packet->payload->mark,packet);
				if (status < 0)
					fprintf(stderr,"Failed to queue packet\n");
				
				break;

			default:
				fprintf(stderr, "Unknown message type!\n");
				break;
		}
	} 

	closeIPQHandle(runnerData->IPQHandle);

	printf("Exiting IPQ runner thread\n");
}


