/*
 * Author: Nigel Kukard  <nkukard@lbsd.net>
 * Desc: Misc functions we can use
 * Date: 01/09/2003
 * License: GPL
*/


#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <time.h>
#include <common.h>


// Convert everything between start & end into an integer
int aptrtoi(char *start, char *end)
{
	char *str = alloca(1024);

	if (!start)
		return 0;

	if (end)
		strncpy(str,start,end - start);
	else
		strcpy(str,start);

	return atoi(str);
}


// Convert datetime format into unix time format
int parseDateTime(char *dateTime)
{
	char *sday, *smonth, *syear, *shour, *sminute, *ssecond;
	int day = 0, month = 0, year = 0, hour = 0, minute = 0, second = 0;
	struct tm time_p;
	int ret;
	
	
	// Convert all values we need
	sday = dateTime;
	if (!sday)
	{
		fprintf(stderr,"ERROR: Failed to find \"day\" in date specified - %s",dateTime);
		return -1;
	}
	
	smonth = strchr(sday,'/');
	if (!smonth)
	{
		fprintf(stderr,"ERROR: Failed to find \"month\" in date specified - %s",dateTime);
		return -1;
	}
	smonth++;

	// Now we have the next marker, we can process the prev variable	
	day = aptrtoi(sday,smonth);
	
	syear = strchr(smonth,'/');
	if (!syear)
	{
		fprintf(stderr,"ERROR: Failed to find \"year\" in date specified - %s",dateTime);
		return -1;
	}
	syear++;

	// And so forth	
	month = aptrtoi(smonth,syear);

	// Here we have a shorter version, we don't really need hour/min/sec
	shour = strchr(syear,' ');
	if (shour)
		shour++;

	year = aptrtoi(syear,shour);

	
	// Check if we have an hour
	if (shour)
	{
		// Same for minutes	
		sminute = strchr(shour,':');
		if (sminute)
			sminute++;
		hour = aptrtoi(shour,sminute);

		// And seconds
		if (sminute)
		{
			ssecond = strchr(sminute,':');
			if (ssecond)
				ssecond++;

			minute = aptrtoi(sminute,ssecond);

			second = aptrtoi(ssecond,NULL);
		}
	}


	// Check all is ok...
	if (day <= 0 || day > 31)
	{
		fprintf(stderr,"Failed to get DAY: %i\n",day);
		return -1;
	}
	
	if (month <= 0 || month > 12)
	{
		fprintf(stderr,"Failed to get MONTH: %i\n",month);
		return -1;
	}

	if (year <= 0)
	{
		fprintf(stderr,"Failed to get YEAR: %i\n",year);
		return -1;
	}

	if (hour < 0 || hour > 23)
	{
		fprintf(stderr,"Failed to get HOUR: %i\n",hour);
		return -1;
	}
	
	if (minute < 0 || minute > 59)
	{
		fprintf(stderr,"Failed to get MINUTE: %i\n",minute);
		return -1;
	}
	
	if (second < 0 || second > 59)
	{
		fprintf(stderr,"Failed to get SECOND: %i\n",second);
		return -1;
	}

	// Setup our struct	
	time_p.tm_mday = day;
	time_p.tm_mon = month - 1;  // Months since Jan
	time_p.tm_year = year - 1900;  // Years since 1900
	time_p.tm_hour = hour;
	time_p.tm_min = minute;
	time_p.tm_sec = second;

	// Return our time construction
	ret = mktime(&time_p);
	return(ret);
}


// Format a counter which is in long long int into a nice looking string value
char *counterFMT(char *unit, double value)
{
	char *buffer;
	double myValue = value;
	int level = 0;
	char *prefix;


	prefix = alloca(1);
	
	// Down our value by dividing by 1024 till we below 1000 or we hit Giga	
	while (myValue > 1000 && level <= 4)
	{
		level++;
		myValue /= 1024;
	}

	// Check what level we at
	switch (level)
	{
		case 0:
			prefix = "";
			break;
		case 1: 
			prefix = "K"; 
			break;
		case 2:
			prefix = "M";
			break;
		case 3:
			prefix = "G";
			break;
		case 4:
			prefix = "T";
			break;
	}

	// Write to buffer and return
	buffer = (char *) malloc0(BUFFER_SIZE);
	snprintf(buffer,BUFFER_SIZE,"%.2f %s%s",myValue,prefix,unit);

	return(buffer);
}


// Function to send all data to a socket and not just chunks
int sendall(int sock, void *buf, int len)
{
	int total = 0;        // how many bytes we've sent
	int bytesleft = len; // how many we have left to send
	int n;


	while(total < len) 
	{
		n = send(sock, buf + total, bytesleft, MSG_NOSIGNAL);
		if (n == -1) 
			break;
		total += n;
		bytesleft -= n;
	}

	return n == -1 ? -1 : 0; // return -1 on failure, 0 on success
} 


